Load cleaned team staff data from the volleydata repository.
Source:R/get_data.R
load_team_staff.RdLoad cleaned team staff data from the volleydata repository.
Value
A data frame containing the team staff data for the specified seasons.
| Column Name | Type |
| match_id | dbl |
| season | dbl |
| match_datetime | chr |
| team_name | chr |
| staff_type | chr |
| full_name | chr |
| first_name | chr |
| last_name | chr |
| league | chr |
Examples
try({load_team_staff("mlv", 2024)})
#> # A tibble: 352 × 9
#> match_id season match_datetime team_name staff_type full_name first_name
#> <dbl> <dbl> <dttm> <chr> <chr> <chr> <chr>
#> 1 2125268 2024 2024-01-26 00:00:00 Grand Ra… coach Cathy Ge… Cathy
#> 2 2125268 2024 2024-01-26 00:00:00 Grand Ra… assistant1 Bill Wal… Bill
#> 3 2125268 2024 2024-01-26 00:00:00 Grand Ra… assistant2 Denis Di… Denis
#> 4 2125268 2024 2024-01-26 00:00:00 Columbus… coach Angel Pe… Angel
#> 5 2125268 2024 2024-01-26 00:00:00 Columbus… assistant1 Carlos C… Carlos
#> 6 2125270 2024 2024-02-02 00:00:00 Atlanta … coach Todd Dag… Todd
#> 7 2125270 2024 2024-02-02 00:00:00 Atlanta … assistant1 Brian Do… Brian
#> 8 2125270 2024 2024-02-02 00:00:00 Atlanta … assistant2 Sally Po… Sally
#> 9 2125270 2024 2024-02-02 00:00:00 San Dieg… coach Tayyiba … Tayyiba
#> 10 2125271 2024 2024-02-04 00:00:00 Omaha Su… coach Shelton … Shelton
#> # ℹ 342 more rows
#> # ℹ 2 more variables: last_name <chr>, league <chr>